diff --git wordpress.org/public_html/wp-content/themes/pub/wporg-forums/page-homepage.php wordpress.org/public_html/wp-content/themes/pub/wporg-forums/page-homepage.php
index 56a391f2d..6412ead24 100644
--- wordpress.org/public_html/wp-content/themes/pub/wporg-forums/page-homepage.php
+++ wordpress.org/public_html/wp-content/themes/pub/wporg-forums/page-homepage.php
@@ -18,15 +18,15 @@ get_header(); ?>
 
 		<div class="col-6" id="forum-welcome">
 
-			<p class="intro"><?php _e( 'We&rsquo;ve got a variety of resources to help you get the most out of WordPress. Your first stop should be our <a href="https://codex.wordpress.org">documentation</a>, where you&rsquo;ll find information on everything from installing WordPress for the first time to creating your own themes&nbsp;and&nbsp;plugins.', 'wporg-forums' ); ?></p>
+			<p class="intro"><?php _e( 'We&rsquo;ve got a variety of resources to help you get the most out of WordPress. Your first stop should be our <a href="https://wordpress.org/support/">documentation</a>, where you&rsquo;ll find information on everything from installing WordPress for the first time to creating your own themes&nbsp;and&nbsp;plugins.', 'wporg-forums' ); ?></p>
 			<h3><?php _e( 'Getting Started Resources', 'wporg-forums' ); ?></h3>
 			<p><?php _e( 'If you need help getting started with WordPress, try these articles.', 'wporg-forums' ); ?></p>
 			<ul>
-				<li><?php _e( '<a href="https://codex.wordpress.org/Forum_Welcome">Welcome to the WordPress Support Forum</a>', 'wporg-forums' ); ?></li>
-				<li><?php _e( '<a href="https://codex.wordpress.org/New_To_WordPress_-_Where_to_Start">New to WordPress &mdash; Where to Start</a>', 'wporg-forums' ); ?></li>
-				<li><?php _e( '<a href="https://codex.wordpress.org/FAQ_Installation">Frequently Asked Questions about Installing WordPress</a>', 'wporg-forums' ); ?></li>
-				<li><?php _e( '<a href="https://codex.wordpress.org/First_Steps_With_WordPress">First Steps with WordPress</a>', 'wporg-forums' ); ?></li>
-				<li><?php _e( '<a href="https://codex.wordpress.org/Writing_Posts">Writing Posts</a>', 'wporg-forums' ); ?></li>
+				<li><?php _e( '<a href="https://wordpress.org/support/welcome/">Welcome to the WordPress Support Forum</a>', 'wporg-forums' ); ?></li>
+				<li><?php _e( '<a href="https://wordpress.org/support/article/new_to_wordpress_-_where_to_start/">New to WordPress &mdash; Where to Start</a>', 'wporg-forums' ); ?></li>
+				<li><?php _e( '<a href="https://wordpress.org/support/article/faq-installation/">Frequently Asked Questions about Installing WordPress</a>', 'wporg-forums' ); ?></li>
+				<li><?php _e( '<a href="https://wordpress.org/support/article/first-steps-with-wordpress/">First Steps with WordPress</a>', 'wporg-forums' ); ?></li>
+				<li><?php _e( '<a href="https://wordpress.org/support/article/writing-posts/">Writing Posts</a>', 'wporg-forums' ); ?></li>
 				<li><?php _e( '<a href="https://make.wordpress.org/support/handbook/">Support Handbook</a>', 'wporg-forums' ); ?></li>
 				<li><?php _e( '<a href="https://make.wordpress.org/support/handbook/contributing-to-the-wordpress-forums/support-forums-in-your-language/">Support Forums in Your Language</a>', 'wporg-forums' ); ?></li>
 			</ul>
diff --git wordpress.org/public_html/wp-content/themes/pub/wporg-support/header.php wordpress.org/public_html/wp-content/themes/pub/wporg-support/header.php
index c3e924364..016b5e58c 100644
--- wordpress.org/public_html/wp-content/themes/pub/wporg-support/header.php
+++ wordpress.org/public_html/wp-content/themes/pub/wporg-support/header.php
@@ -14,7 +14,7 @@ namespace WordPressdotorg\Forums;
 $menu_items = array(
 	/* translators: relative link to the forums home page */
 	_x( '/forums/', 'header menu', 'wporg-forums' )                                     => _x( 'Forums', 'header menu', 'wporg-forums' ),
-	_x( 'https://codex.wordpress.org/Main_Page', 'header menu', 'wporg-forums' )        => _x( 'Documentation', 'header menu', 'wporg-forums' ),
+	_x( 'https://wordpress.org/support/', 'header menu', 'wporg-forums' )        		=> _x( 'Documentation', 'header menu', 'wporg-forums' ),
 	_x( 'https://make.wordpress.org/support/handbook/', 'header menu', 'wporg-forums' ) => _x( 'Get Involved', 'header menu', 'wporg-forums' ),
 );
 
diff --git wordpress.org/public_html/wp-content/themes/pub/wporg-support/page-homepage.php wordpress.org/public_html/wp-content/themes/pub/wporg-support/page-homepage.php
index edb88bfa5..05ea8d831 100644
--- wordpress.org/public_html/wp-content/themes/pub/wporg-support/page-homepage.php
+++ wordpress.org/public_html/wp-content/themes/pub/wporg-support/page-homepage.php
@@ -42,7 +42,7 @@ get_header(); ?>
 					?>"></span>
 					<h3><?php _e( 'Documentation', 'wporg-forums' ); ?></h3>
 					<p><?php _e( 'Your first stop where you\'ll find information on everything from installing to creating plugins.', 'wporg-forums' ); ?></p>
-					<p><?php _e( '<a href="https://codex.wordpress.org/">Explore documentation</a>', 'wporg-forums' ); ?></p>
+					<p><?php _e( '<a href="https://wordpress.org/support/">Explore documentation</a>', 'wporg-forums' ); ?></p>
 				</div>
 			</div>
 			<div>
@@ -76,10 +76,10 @@ get_header(); ?>
 			<div>
 				<h3><?php _e( 'Helpful Links', 'wporg-forums' ); ?></h3>
 				<ul class="meta-list">
-					<li><?php _e( '<a href="https://codex.wordpress.org/New_To_WordPress_-_Where_to_Start">New to WordPress &mdash; Where to Start</a>', 'wporg-forums' ); ?></li>
-					<li><?php _e( '<a href="https://codex.wordpress.org/FAQ_Installation">Frequently Asked Questions about Installing WordPress</a>', 'wporg-forums' ); ?></li>
-					<li><?php _e( '<a href="https://codex.wordpress.org/First_Steps_With_WordPress">First Steps with WordPress</a>', 'wporg-forums' ); ?></li>
-					<li><?php _e( '<a href="https://codex.wordpress.org/Writing_Posts">Writing Posts</a>', 'wporg-forums' ); ?></li>
+					<li><?php _e( '<a href="https://wordpress.org/support/article/new_to_wordpress_-_where_to_start/">New to WordPress &mdash; Where to Start</a>', 'wporg-forums' ); ?></li>
+					<li><?php _e( '<a href="https://wordpress.org/support/article/faq-installation/">Frequently Asked Questions about Installing WordPress</a>', 'wporg-forums' ); ?></li>
+					<li><?php _e( '<a href="https://wordpress.org/support/article/first-steps-with-wordpress-classic/">First Steps with WordPress</a>', 'wporg-forums' ); ?></li>
+					<li><?php _e( '<a href="https://wordpress.org/support/article/writing-posts/">Writing Posts</a>', 'wporg-forums' ); ?></li>
 				</ul>
 			</div>
 		</section>
diff --git wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/bbpress-front.php wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/bbpress-front.php
index a68b53cca..b901879c3 100644
--- wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/bbpress-front.php
+++ wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/bbpress-front.php
@@ -2,7 +2,7 @@
 /**
  * Template part for displaying bbPress topics on the front page.
  *
- * @link https://codex.wordpress.org/Template_Hierarchy
+ * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
  *
  * @package WPBBP
  */
@@ -37,7 +37,7 @@
 					"></span>
 			<h3><?php _e( 'Documentation', 'wporg-forums' ); ?></h3>
 			<p><?php _e( 'Your first stop where you\'ll find information on everything from installing to creating plugins.', 'wporg-forums' ); ?></p>
-			<p><?php _e( '<a href="https://codex.wordpress.org/">Explore documentation</a>', 'wporg-forums' ); ?></p>
+			<p><?php _e( '<a href="https://wordpress.org/support/">Explore documentation</a>', 'wporg-forums' ); ?></p>
 		</div>
 	</div>
 	<div>
diff --git wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/content-archive.php wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/content-archive.php
index ef968bfd2..06996b513 100644
--- wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/content-archive.php
+++ wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/content-archive.php
@@ -2,7 +2,7 @@
 /**
  * Template part for displaying single posts in an archive list.
  *
- * @link https://codex.wordpress.org/Template_Hierarchy
+ * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
  *
  * @package WPBBP
  */
diff --git wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/content-page.php wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/content-page.php
index bda05dfeb..5ec38f02b 100644
--- wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/content-page.php
+++ wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/content-page.php
@@ -2,7 +2,7 @@
 /**
  * Template part for displaying page content in page.php.
  *
- * @link https://codex.wordpress.org/Template_Hierarchy
+ * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
  *
  * @package WPBBP
  */
diff --git wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/content-single.php wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/content-single.php
index c7824163b..428d5040c 100644
--- wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/content-single.php
+++ wordpress.org/public_html/wp-content/themes/pub/wporg-support/template-parts/content-single.php
@@ -2,7 +2,7 @@
 /**
  * Template part for displaying page content in page.php.
  *
- * @link https://codex.wordpress.org/Template_Hierarchy
+ * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
  *
  * @package WPBBP
  */

diff --git wordpress.org/public_html/wp-content/themes/pub/wporg-forums/bbpress/form-topic.php wordpress.org/public_html/wp-content/themes/pub/wporg-forums/bbpress/form-topic.php
index 77642d8c3..b8768c49b 100644
--- wordpress.org/public_html/wp-content/themes/pub/wporg-forums/bbpress/form-topic.php
+++ wordpress.org/public_html/wp-content/themes/pub/wporg-forums/bbpress/form-topic.php
@@ -41,8 +41,8 @@
 						<p><?php _e( 'When posting a new topic, follow these steps:', 'wporg-forums' ); ?></p>
 						<ul>
 							<li><?php
-								/* translators: %s: Codex URL for forum welcome */
-								printf( __( '<strong>Read the <a href="%s">Forum Welcome</a></strong> to find out how to maximize your odds of getting help!', 'wporg-forums' ), esc_url( __( 'https://codex.wordpress.org/Forum_Welcome', 'wporg-forums' ) ) );
+								/* translators: %s: Support URL for forum welcome */
+								printf( __( '<strong>Read the <a href="%s">Forum Welcome</a></strong> to find out how to maximize your odds of getting help!', 'wporg-forums' ), esc_url( __( 'https://wordpress.org/support/welcome/', 'wporg-forums' ) ) );
 							?></li>
 							<li><?php
 								/* translators: %s: URL to search */